===============================
How to add GitHub Access Tokens
===============================

This article will show you how you can add a GitHub access token
to your profile, to allow your software environment to include 
packages from private GitHub repositories.

Your Coiled Profile
-------------------

Access credentials are stored on `your profile <https://cloud.coiled.io/profile>`_, 
which can be accessed by clicking on your avatar or initial in the upper right 
corner of any coiled cloud page, such as your dashboard. 

.. figure:: ../images/coiled-profile.png

Once there, scroll down and simply add your token.

.. figure:: ../images/github-add-token.png